@@ -45,7 +45,7 @@ our @EXPORT = qw(
     psquares
     %font2map
 );
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 our %font2map = (
     'Chess Cases'           => 'leschemelle',
@@ -1232,17 +1232,44 @@ sub epdTaxonomy {
 1;
 __END__
 
+=for readme start
+
 =head1 NAME
 
 Chess::PGN::EPD - Perl extension to produce and manipulate EPD text.
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 SYNOPSIS
 
-=head1 CODE examples
+From "Working With Epd Files" by Steve Lopez <http://www.chessbaseusa.com/portals/6/tn/Issues_Back/1999_autumn/1999_1031.htm>,
+
+"There's a lot of chess information available on the Internet in a variety of formats. One of these is called
+EPD (Extended Position Description) format; it's just a convenient way to provide a board position (rather than
+a full game) in an ASCII text notation. For example, here's what the board position after 1.e4 looks like in
+EPD format:
+
+    rnbqkbnr/pppppppp/8/8/4P3/8/PPPP1PPP/RNBQKBNR b KQkq e3 0 1
+
+This was designed as a way for chess players and chess programs to pass board positions back and forth for
+analysis. You'll frequently see posts to Usenet chess newsgroups or other message boards containing these
+EPD positions.
+
+There's a quick, easy way to copy and paste these board descriptions into ChessBase or any of our playing programs
+(Fritz, Hiarcs, Nimzo, Junior). Just highlight the EPD line from a post or web page and hit CRTL-C on your keyboard.
+Then open ChessBase, go to the Game menu, select "Setup position", and click the button marked "Paste FEN". You'll
+instantly see the position appear on the board in the "Setup position" window. Click "OK" and you'll now have an
+"Enter new game" window with the proper board position on it taken from the EPD file. You can then save the position
+into a database just like any other game..."
+
+Chess::PGN::EPD attempts to bring ease and convenience to its users programmatically by providing a set of
+functions that manipulate EPD text.
+
+=for readme stop
+
+=head2 CODE examples
 
 B<THIS>
 
@@ -1253,7 +1280,7 @@ B<THIS>
  use strict;
  use Chess::PGN::Parse;
  use Chess::PGN::EPD;
- 
+
  if ($ARGV[0]) {
      my $pgn = new Chess::PGN::Parse($ARGV[0]) or die "Can't open $ARGV[0]: $!\n";
      while ($pgn->read_game()) {
@@ -1283,12 +1310,12 @@ B<OR>
  use warnings;
  use Chess::PGN::Parse;
  use Chess::PGN::EPD;
- 
+
  if ($ARGV[0]) {
      my $pgn = new Chess::PGN::Parse($ARGV[0]) or die "Can't open $ARGV[0]: $!\n";
      while ($pgn->read_game()) {
          my @epd;
- 
+
          $pgn->parse_game();
          my @moves = @{ $game{'GameMoves'} };
          print join("\n",epdTaxonomy(moves => \@moves,all => 1,astags => 1)),"\n";
@@ -1312,8 +1339,8 @@ Allowed codes are:
 
 =back
 
-At the moment, this routine depends on three Storable files installed along with
-the module. On demand other database formats may be implemented. The 'ToDo' list
+At the moment, this routine depends on three database files installed along with
+the module. On demand other formats (the current is JSON) may be implemented. The 'ToDo' list
 also mentions the possibility of extending the databases, although that might come in
 the form of a 'How To' rather than any code solution. NOTE: This routine is deprecated
 in favor of epdTaxonomy and will at some point be removed.
@@ -1420,7 +1447,7 @@ A FEN description has six fields.  Each field is composed only of non-blank
 printing ASCII characters.  Adjacent fields are separated by a single ASCII
 space character.
 
-=over 
+=over
 
 =item Piece placement data
 
@@ -1539,9 +1566,9 @@ A plain ASCII diagram with simple border showing rank and file. Typical output:
  8  rnbqkb r
  7  ppp pppp
  6   - - n -
- 5  - -P- - 
+ 5  - -P- -
  4   - - - -
- 3  - - - - 
+ 3  - - - -
  2  PPPP PPP
  1  RNBQKBNR
     abcdefgh
@@ -1553,9 +1580,9 @@ A plain ASCII diagram. Typical output:
  rnbqkb r
  ppp pppp
   - - n -
- - -P- - 
+ - -P- -
   - - - -
- - - - - 
+ - - - -
  PPPP PPP
  RNBQKBNR
 
@@ -1564,26 +1591,26 @@ A plain ASCII diagram. Typical output:
 An array of HTML information that represents the tabular diagram information for PalView.
 Typical output:
 
-<IMG SRC="jpc/br.gif"><IMG SRC="jpc/bn.gif"><IMG SRC="jpc/bb.gif"><IMG SRC="jpc/bq.gif"><IMG 
+<IMG SRC="jpc/br.gif"><IMG SRC="jpc/bn.gif"><IMG SRC="jpc/bb.gif"><IMG SRC="jpc/bq.gif"><IMG
 SRC="jpc/bk.gif"><IMG SRC="jpc/bb.gif"><IMG SRC="jpc/bn.gif"><IMG SRC="jpc/br.gif"><BR>
-<IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG 
+<IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG
 SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><IMG SRC="jpc/bp.gif"><BR>
-<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG 
+<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG
 SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><BR>
-<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG 
+<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG
 SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><BR>
-<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG 
+<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG
 SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><BR>
-<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG 
+<IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG
 SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/wn.gif"><BR>
-<IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG 
+<IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG
 SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><IMG SRC="jpc/wp.gif"><BR>
-<IMG SRC="jpc/wr.gif"><IMG SRC="jpc/wn.gif"><IMG SRC="jpc/wb.gif"><IMG SRC="jpc/wq.gif"><IMG 
+<IMG SRC="jpc/wr.gif"><IMG SRC="jpc/wn.gif"><IMG SRC="jpc/wb.gif"><IMG SRC="jpc/wq.gif"><IMG
 SRC="jpc/wk.gif"><IMG SRC="jpc/wb.gif"><IMG SRC="jpc/i.gif"><IMG SRC="jpc/wr.gif"><BR>
 
 =item 'latex'
 
-The necessary text fragment to 'set' the diagram in LaTeX using 
+The necessary text fragment to 'set' the diagram in LaTeX using
 any variation of Piet Tutelars original chess12.tar.Z package. As given, the LaTeX
 command 'diagram' is used. As an example here is the source to test.tex:
 
@@ -1798,7 +1825,7 @@ names and information:
      my $pgn = new Chess::PGN::Parse($ARGV[0]) or die "Can't open $ARGV[0]: $!\n";
      while ($pgn->read_game()) {
          my @epd;
- 
+
          $pgn->parse_game();
          @epd = reverse epdlist( @{$pgn->moves()} );
          print '[ECO,"',epdcode('ECO',\@epd),"\"]\n";
@@ -1815,7 +1842,7 @@ all of the above with:
      my $pgn = new Chess::PGN::Parse($ARGV[0]) or die "Can't open $ARGV[0]: $!\n";
      while ($pgn->read_game()) {
          my @epd;
- 
+
          $pgn->parse_game();
          my @moves = @{ $game{'GameMoves'} };
          print join("\n",epdTaxonomy(moves => \@moves,all => 1,astags => 1)),"\n";
@@ -1857,7 +1884,7 @@ piece.
 
 =item epdfromto - given a list of moves, return an array of hashes which contain move information.
 
-=item epdgetboard - given an EPD string setup board and related. Either way return board and related 
+=item epdgetboard - given an EPD string setup board and related. Either way return board and related
 information.
 
 =item epdlist - given a list of moves, return a list of EPD strings.
@@ -1868,7 +1895,7 @@ information.
 
 =item epdTaxonomy - one stop shopping for conversion of epd array to ECO, NIC and opening tag information.
 
-=item psquares - given the piece and the board, generate and return a list of squares occupied by that 
+=item psquares - given the piece and the board, generate and return a list of squares occupied by that
 type of piece.
 
 =back
@@ -1877,17 +1904,17 @@ type of piece.
 
 =over
 
-=item Chess::PGN::Moves     => 0.04
+=item Chess::PGN::Moves     => 0.05
 
-=item Chess::PGN::Parse     => 0.19
+=item Chess::PGN::Parse     => 0.20
 
 =item Test::More            => 0.94
 
-=item File::ShareDir	    => 1.102
+=item File::ShareDir        => 1.102
 
-=item File::Slurper	        => 0.008
+=item File::Slurper         => 0.008
 
-=item Cpanel::JSON::XS	    => 3.0213
+=item Cpanel::JSON::XS      => 3.0213
 
 =back
 
@@ -1909,12 +1936,166 @@ type of piece.
 
 None known; Unknown? Of course, though I try to be neat...
 
+=for readme start
+
+=for readme plugin version
+
+=for readme plugin changes
+
+=for readme plugin requires
+
+=head1 INSTALLATION
+
+Traditional recipe based on Makefile.PL:
+
+    perl Makefile.PL
+    make
+    make test
+    make install
+
+Note that some distributions will have a Build.PL file instead of
+or in addition to Makefile.PL. In that case use this recipe:
+
+    perl Build.PL
+    ./Build
+    ./Build test
+    ./Build install
+
 =head1 AUTHOR
 
-B<I<Hugh S. Myers>>
+Hugh S. Myers <hsmyers@gmail.com>
 
-=over
+=head1 LICENSE
 
-=item Always: hsmyers@gmail.com
+             The "Artistic License"
 
-=back
+                Preamble
+
+The intent of this document is to state the conditions under which a
+Package may be copied, such that the Copyright Holder maintains some
+semblance of artistic control over the development of the package,
+while giving the users of the package the right to use and distribute
+the Package in a more-or-less customary fashion, plus the right to make
+reasonable modifications.
+
+Definitions:
+
+    "Package" refers to the collection of files distributed by the
+    Copyright Holder, and derivatives of that collection of files
+    created through textual modification.
+
+    "Standard Version" refers to such a Package if it has not been
+    modified, or has been modified in accordance with the wishes
+    of the Copyright Holder as specified below.
+
+    "Copyright Holder" is whoever is named in the copyright or
+    copyrights for the package.
+
+    "You" is you, if you're thinking about copying or distributing
+    this Package.
+
+    "Reasonable copying fee" is whatever you can justify on the
+    basis of media cost, duplication charges, time of people involved,
+    and so on.  (You will not be required to justify it to the
+    Copyright Holder, but only to the computing community at large
+    as a market that must bear the fee.)
+
+    "Freely Available" means that no fee is charged for the item
+    itself, though there may be fees involved in handling the item.
+    It also means that recipients of the item may redistribute it
+    under the same conditions they received it.
+
+1. You may make and give away verbatim copies of the source form of the
+Standard Version of this Package without restriction, provided that you
+duplicate all of the original copyright notices and associated disclaimers.
+
+2. You may apply bug fixes, portability fixes and other modifications
+derived from the Public Domain or from the Copyright Holder.  A Package
+modified in such a way shall still be considered the Standard Version.
+
+3. You may otherwise modify your copy of this Package in any way, provided
+that you insert a prominent notice in each changed file stating how and
+when you changed that file, and provided that you do at least ONE of the
+following:
+
+    a) place your modifications in the Public Domain or otherwise make them
+    Freely Available, such as by posting said modifications to Usenet or
+    an equivalent medium, or placing the modifications on a major archive
+    site such as uunet.uu.net, or by allowing the Copyright Holder to include
+    your modifications in the Standard Version of the Package.
+
+    b) use the modified Package only within your corporation or organization.
+
+    c) rename any non-standard executables so the names do not conflict
+    with standard executables, which must also be provided, and provide
+    a separate manual page for each non-standard executable that clearly
+    documents how it differs from the Standard Version.
+
+    d) make other distribution arrangements with the Copyright Holder.
+
+4. You may distribute the programs of this Package in object code or
+executable form, provided that you do at least ONE of the following:
+
+    a) distribute a Standard Version of the executables and library files,
+    together with instructions (in the manual page or equivalent) on where
+    to get the Standard Version.
+
+    b) accompany the distribution with the machine-readable source of
+    the Package with your modifications.
+
+    c) give non-standard executables non-standard names, and clearly
+    document the differences in manual pages (or equivalent), together
+    with instructions on where to get the Standard Version.
+
+    d) make other distribution arrangements with the Copyright Holder.
+
+5. You may charge a reasonable copying fee for any distribution of this
+Package.  You may charge any fee you choose for support of this
+Package.  You may not charge a fee for this Package itself.  However,
+you may distribute this Package in aggregate with other (possibly
+commercial) programs as part of a larger (possibly commercial) software
+distribution provided that you do not advertise this Package as a
+product of your own.  You may embed this Package's interpreter within
+an executable of yours (by linking); this shall be construed as a mere
+form of aggregation, provided that the complete Standard Version of the
+interpreter is so embedded.
+
+6. The scripts and library files supplied as input to or produced as
+output from the programs of this Package do not automatically fall
+under the copyright of this Package, but belong to whoever generated
+them, and may be sold commercially, and may be aggregated with this
+Package.  If such scripts or library files are aggregated with this
+Package via the so-called "undump" or "unexec" methods of producing a
+binary executable image, then distribution of such an image shall
+neither be construed as a distribution of this Package nor shall it
+fall under the restrictions of Paragraphs 3 and 4, provided that you do
+not represent such an executable image as a Standard Version of this
+Package.
+
+7. C subroutines (or comparably compiled subroutines in other
+languages) supplied by you and linked into this Package in order to
+emulate subroutines and variables of the language defined by this
+Package shall not be considered part of this Package, but are the
+equivalent of input as in Paragraph 6, provided these subroutines do
+not change the language in any way that would cause it to fail the
+regression tests for the language.
+
+8. Aggregation of this Package with a commercial distribution is always
+permitted provided that the use of this Package is embedded; that is,
+when no overt attempt is made to make this Package's interfaces visible
+to the end user of the commercial distribution.  Such use shall not be
+construed as a distribution of this Package.
+
+9. The name of the Copyright Holder may not be used to endorse or promote
+products derived from this software without specific prior written permission.
+
+10. THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
+IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
+WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+                The End
+
+=head1 COPYRIGHT
+
+Copyright (C) 2017 Hugh S. Myers
+=end :readme
